@@ -15,8 +15,21 @@ BayesProbitHSD.Summary = function(object, digits = max(1L, getOption("digits") -
 
     beta.est.CI = as.data.frame(cbind(beta.est, t(beta.CI)))
 
-    beta.est.CI = format(beta.est.CI, digits = digits)
 
+
+    if(!is.null(post.samples$alpha.samples)){
+        alpha.est = matrix(unlist(apply(post.samples$alpha.samples, 1, bm)), ncol = 2, byrow=TRUE)
+        alpha.CI = t(apply(post.samples$alpha.samples, 1, quantile, c(0.025, 0.975)))
+        alpha.est = alpha.est[-c(1, nrow(alpha.est)), ]
+        alpha.CI = alpha.CI[-c(1, nrow(alpha.CI)), ]
+        colnames(alpha.est) = c("PostMean", "StErr")
+        rownames(alpha.est) = paste0("alpha", 1:nrow(alpha.est))
+        alpha.est.CI = as.data.frame(cbind(alpha.est, alpha.CI))
+        beta.est.CI = rbind(beta.est.CI, alpha.est.CI)
+    }
+
+
+    beta.est.CI = format(beta.est.CI, digits = digits)
     #cat("\nCoefficients:\n")
     #print(beta.est.CI)
 
