@@ -13,19 +13,21 @@
 #' It requires an ``integer'' variable named by \samp{id} to denote the identifications of subjects. 
 #' @param random a one-sided linear formula object to describe random-effects with the terms separated by 
 #' \samp{+} or \samp{*} operators on the right of a \samp{~} operator.
-#' @param Robustness logical. If 'TRUE' the distribution of random effects is assumed to be t-distribution; 
-#' otherwise normal distribution. 
+#' @param Robustness logical. If 'TRUE' the distribution of random effects is assumed to be \cr
+#' t-distribution; otherwise normal distribution. 
 #' @param na.action a function that indicates what should happen when the data contain NA’s. 
-#' The default action (\samp{na.omit}, inherited from the \samp{factory fresh} value of 
+#' The default action (\samp{na.omit}, inherited from the \samp{factory fresh} value of \cr
 #' \samp{getOption("na.action")}) strips any observations with any missing values in any variables.
 #' @param subset an optional expression indicating the subset of the rows of \samp{data} that should be used in the fit. 
 #' This can be a logical vector, or a numeric vector indicating which observation numbers are to be included, 
 #' or a character vector of the row names to be included.  All observations are included by default.
-#' @param HS.model a specification of the correlation structure in HSD model: \code{HS.model = ~0} denotes 
-#' independence, that is, \eqn{R_i} is an identity matrix,  
-#' \code{HS.model = ~IndTime+}\eqn{\cdots}\code{+IndTimer} denotes AR(r) correlation structure, 
-#' \code{HS.model = ~DiffTime1+}\eqn{\cdots}\code{+DiffTimer} denotes correlation structure related to \eqn{r}th order 
+#' @param HS.model a specification of the correlation structure in HSD model: 
+#' \itemize{
+#'   \item \code{HS.model = ~0} denotes independence, that is, \eqn{R_i} is an identity matrix, 
+#'   \item \code{HS.model = ~IndTime+}\eqn{\cdots}\code{+IndTimer} denotes AR(r) correlation structure, 
+#'   \item \code{HS.model = ~DiffTime1+}\eqn{\cdots}\code{+DiffTimer} denotes correlation structure related to \eqn{r}th order 
 #' of time difference. 
+#' }
 #' @param arma.order a specification of the order in an ARMA model: the two integer components (p, q) are the AR order and the MA order.
 #' @param hyper.params specify the values in hyperparameters in priors. 
 #' @param num.of.iter an integer to specify the total number of iterations; default is 20000.   
@@ -62,13 +64,16 @@
 #' w = array(runif(T*T*a), c(T, T, a)) #design matrix in HSD model
 #' 
 #' for(time.diff in 1:a)
-#' 	w[, , time.diff] = 1*(as.matrix(dist(1:T, 1:T, method="manhattan")) ==time.diff)
+#' 	w[, , time.diff] = 1*(as.matrix(dist(1:T, 1:T, method="manhattan")) 
+#'  ==time.diff)
 #' 
 #' #Generate a data with HSD model
-#' HSD.sim.data = SimulatedDataGenerator(Num.of.Obs = N, Num.of.TimePoints = T, 
-#'	Fixed.Effs = Fixed.Effs, Random.Effs = list(Sigma = 0.5*diag(1), df=3), 
-#'	Cor.in.DesignMat = 0., Missing = list(Missing.Mechanism = 2, RegCoefs = c(-1.5, 1.2)), 
-#'	Cor.Str = "HSD", HSD.DesignMat.para = list(HSD.para = HSD.para, DesignMat = w))
+#'  HSD.sim.data = SimulatedDataGenerator(
+#'  Num.of.Obs = N, Num.of.TimePoints = T, Fixed.Effs = Fixed.Effs, 
+#'  Random.Effs = list(Sigma = 0.5*diag(1), df=3), 
+#'	Cor.in.DesignMat = 0., Missing = list(Missing.Mechanism = 2, 
+#'  RegCoefs = c(-1.5, 1.2)), Cor.Str = "HSD", 
+#'  HSD.DesignMat.para = list(HSD.para = HSD.para, DesignMat = w))
 #' 
 #' hyper.params = list(
 #'         sigma2.beta = 1,
@@ -77,9 +82,11 @@
 #'         InvWishart.df = 5,
 #'         InvWishart.Lambda = diag(q) )
 #' 
-#' HSD.output = BayesRobustProbit(fixed = as.formula(paste("y~-1+", paste0("x", 1:P, collapse="+"))), 
-#' 	data=HSD.sim.data$sim.data, random = ~ 1, Robustness=TRUE, HS.model = ~IndTime1+IndTime2, 
-#'  subset = NULL, na.action='na.exclude', hyper.params = hyper.params, num.of.iter = num.of.iter, 
+#' HSD.output = BayesRobustProbit(
+#' fixed = as.formula(paste("y~-1+", paste0("x", 1:P, collapse="+"))), 
+#' data=HSD.sim.data$sim.data, random = ~ 1, Robustness=TRUE, 
+#' HS.model = ~IndTime1+IndTime2, subset = NULL, na.action='na.exclude', 
+#' hyper.params = hyper.params, num.of.iter = num.of.iter, 
 #'  Interactive=0)
 #' } 
 
@@ -87,6 +94,7 @@ BayesRobustProbit = function(fixed, data, random, Robustness=TRUE, subset=NULL,
 	                         HS.model=NULL, hyper.params = NULL, num.of.iter=20000, Interactive=FALSE)
 { 
 
+	
 	#cat("\nCall:\n", printCall(match.call()), "\n\n", sep = "")
 
 	if(length(arma.order)==0 && length(HS.model)==0)
@@ -94,15 +102,22 @@ BayesRobustProbit = function(fixed, data, random, Robustness=TRUE, subset=NULL,
 	if(length(arma.order)!=0 && length(HS.model)!=0)
 		stop("Please specify only one model for the correlation structure!!")
 
-	if(length(arma.order)>0)
-		output = do.call("BayesProbitARMA", list(fixed=fixed, data=data, random=random, Robustness=Robustness, 
-			subset=subset, na.action=na.action, arma.order=arma.order, hyper.params = hyper.params, 
-			num.of.iter=num.of.iter, Interactive = Interactive))
-	if(length(HS.model)>0)
-		output = do.call("BayesProbitHSD", list(fixed=fixed, data=data, random=random, Robustness=Robustness, 
-			subset=subset, na.action=na.action, HS.model=HS.model, hyper.params = hyper.params, 
-			num.of.iter=num.of.iter, Interactive = Interactive))
-		#output = BayesProbitHSD(fixed, data, random, HS.model, subset=NULL, na.action, num.of.iter)
+	if( length(unique(na.omit(data[, names(data)==all.vars(fixed)[1]])))>2 ){
+		output = do.call("BayesCumulativeProbitHSD", list(fixed=fixed, data=data, random=random, Robustness=Robustness, 
+				subset=subset, na.action=na.action, HS.model=HS.model, hyper.params = hyper.params, 
+				num.of.iter=num.of.iter, Interactive = Interactive))
+	}
+	else{
+		if(length(arma.order)>0)
+			output = do.call("BayesProbitARMA", list(fixed=fixed, data=data, random=random, Robustness=Robustness, 
+				subset=subset, na.action=na.action, arma.order=arma.order, hyper.params = hyper.params, 
+				num.of.iter=num.of.iter, Interactive = Interactive))
+		if(length(HS.model)>0)
+			output = do.call("BayesProbitHSD", list(fixed=fixed, data=data, random=random, Robustness=Robustness, 
+				subset=subset, na.action=na.action, HS.model=HS.model, hyper.params = hyper.params, 
+				num.of.iter=num.of.iter, Interactive = Interactive))
+			#output = BayesProbitHSD(fixed, data, random, HS.model, subset=NULL, na.action, num.of.iter)
+	}
 
 	output$call$data = deparse(substitute(data))
 	#print(output$call$data)
